@@ -258,12 +258,25 @@ def cmd_2_image (app, plot):
         print(c)
         os.system(c)
     if (args[0] == "ditaa") and (plot_format in ['pdf']):
-        # In fact ditaa don't support pdf, we convert the .svg to .pdf.
+        # In fact ditaa don't support pdf, we convert the .svg to .pdf inkscape
         print("mv %s %s-%s.svg" %(outfname, args[0], hashkey))
         os.system("mv %s %s-%s.svg" %(outfname, args[0], hashkey))
-        print("inkscape -f %s-%s.svg -A %s" %(args[0], hashkey, out["outfullfn"]))
-        os.system("inkscape -f %s-%s.svg -A %s" %(args[0], hashkey, out["outfullfn"]))
 
+        inkscape = os.system("which inkscape 2> /dev/null")
+        if inkscape != 0:
+            print('[1;31minkscape does not exist, isntall it at first[0m')
+        inkscape = os.popen("inkscape --version | awk  '{print $2}'") 
+        #print(int(inkscape.read().split(".")[0]))
+        if (int(inkscape.read().split(".")[0], 10) >= 1):
+            print("inkscape %s-%s.svg --export-type pdf -o %s"
+                    %(args[0], hashkey, out["outfullfn"]))
+            os.system("inkscape %s-%s.svg --export-type pdf -o %s"
+                    %(args[0], hashkey, out["outfullfn"]))
+        else:
+            print("inkscape -f %s-%s.svg -A %s"
+                    %(args[0], hashkey, out["outfullfn"]))
+            os.system("inkscape -f %s-%s.svg -A %s"
+                    %(args[0], hashkey, out["outfullfn"]))
 
     # 3) Check if it's need to generate the outreference file
     if options.get("show_source", False):
